using System.Reflection;
using System.Runtime.CompilerServices;

[assembly:AssemblyVersion("2.0.0.76")]
[assembly:AssemblyTitle("Mono.Zeroconf")]
[assembly:AssemblyDescription("Cross Platform Zeroconf for .NET")]
[assembly:AssemblyCopyright("Copyright (C) 2006-2008 Novell, Inc.")]
[assembly:AssemblyCompany("Novell, Inc.")]

